Citing the library
==================

We would be delighted if anyone wanted to use and/or reference this library for
their own research.

If you do please let us know and reference the library:

**Axelrod-Python project team**, *2015*: Axelrod-Python vx.y.z.
http://axelrod-python.github.io/

Here is the corresponding bibtex entry::

    @misc{Axelrod-Pythonprojectteam2015,
    author = {Axelrod-Python project team},
    title = {{Axelrod-Python vx.y.z}},
    url = {http://axelrod-python.github.io/},
    year = {2015}
    }
